%altimeter backscatter model for snow and ice by Rasmus T. Tonboe

function antarcmod(ifile)

d2rf=0.01745329;
ia=0.0;
freq=13.60;
k=20.944.*freq;
eair=1.0+0.0i;
ang_ia=ia .*d2rf;

eval (['load ',ifile])
eval (['di = ',ifile(1:6),'(:,5);']);
ii = find(di > 0);
eval (['num = ',ifile(1:6),'(ii,1);']);
eval (['T = ',ifile(1:6),'(ii,2);']);
eval (['rms = ',ifile(1:6),'(ii,3);']);
eval (['Dens = ',ifile(1:6),'(ii,4);']);
eval (['d = ',ifile(1:6),'(ii,5);']);
eval (['pcc = ',ifile(1:6),'(ii,6);']);
eval (['sal = ',ifile(1:6),'(ii,7);']);
eval (['si = ',ifile(1:6),'(ii,8);']);

%num: layer number
%T: thermometric temperature in C
%rms: layer surface roughness, in UC.m it is the flat-patch-area in [%]
%Dens: density [kg/m3]
%d:layer thickness [m]
%pcc: correlation length in [mm], a measure of grain/inclusion size and distr.
%sal: salinity [psu,ppt]
%si: snow (1) or ice (>1)

n=max(size(num));
if n == 0
   return
endif

%temperature in Kelvin
TK=T+273.15;

%correlation length in meters
pcc=0.001 .*pcc;

for idx=1:n
 if si(idx) == 1
  v(idx)=Dens(idx) ./926;
 else
  v(idx)=Vb(T(idx),sal(idx));
 endif
endfor

%dielectric constant of background and particles
for idx=1:n
  if si(idx) == 1 
    eh(idx)=1.0+0.0i;
    ep(idx)=epice(TK(idx),freq,sal(idx));
  else
    eh(idx)=epice(TK(idx),freq,0);
    ep(idx)=ebrine2(freq,T(idx),sal(idx));
  endif
endfor

%effective dielectric constant using a two-phase PVS form. for spheres
for idx=1:n
    e(idx)=eice_s2p(eh(idx),ep(idx),v(idx));
endfor

e

for idx=1:n
    ang(idx)=0.0;
end

%Fresnell reflection and transmission coefficients

for idx=1:n
  if idx==1
   R(idx)=FR_(0,0,eair,e(idx));
   T(idx)=FT_(ang_ia,ang(idx),eair,e(idx));
  else
   R(idx)=FR_(0,0,e(idx-1),e(idx));
   T(idx)=FT_(ang(idx-1),ang(idx),e(idx-1),e(idx));
  endif
endfor

%scattering and absorption coefficients and Loss

for idx=1:n

ks(idx)=iborn_s2p_sc(eh(idx),ep(idx),e(idx),v(idx),k,pcc(idx));
kb(idx)=iborn_s2p_bc(eh(idx),ep(idx),e(idx),v(idx),k,pcc(idx));
ka(idx)=iborn_s2p_ab(eh(idx),ep(idx),e(idx),v(idx),k);
ke(idx)=ks(idx)+ka(idx);

%loss
loss(idx)=extloss(d(idx),ang(idx),ke(idx));

ss(idx)=UC(R(idx),rms(idx));

endfor

%total backscatter (in dB)
parts=rt(n,kb,ss,loss,T);
tback=10.*log10(sum(parts));
tback

%backscatter from individual layers (incl. vol. scat) corrected for transmission etc.
parts

%waveform: power as a func of time [1E-11s].
[tids,tpower]=waveform(n,0.001.*parts,d,e);

len=max(size(tpower));

thalv=1e-9;
phalv=10000.;
shalv=9999.0;
tpeak=0.0;
ppeak=tpower(len-1);

for idx=1:len-1
 if (tpower(idx)<=(0.5.*tpower(len-1)))
   thalv=tids(idx);
   phalv=tpower(idx);
   shalv=tpower(idx+1)-tpower(idx);
 endif

 if (tpower(idx)-tpower(idx+1) > 1.0) 
   tpeak=tids(idx);
   ppeak=tpower(idx);
 endif
endfor

plot(tids,tpower)

[fnum,err]=fopen('puf.txt',"a");
data=[tids,tpower];
fprintf(fnum,'%5.3f %5.3f\n',data');

endfunction
